hdr-random
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A library based on https://www.probabilitymanagement.org/hdr

## Install

``` sh
pip install hdr_random
```

## How to use

Here is the way to generate a sequence of 1C random numbers: see the
class
[`HDRandom`](https://chrphb.github.io/hdr-random/core.html#hdrandom)

``` python
x = HDRandom(entity=10, varId=2, seed3=3, seed4=4)
for c in range(1,10):
    print(x.generate(counter=c))
```

    0.18532938009593636
    0.9937039703363553
    0.09836426738183945
    0.7941507144132629
    0.7279702170053497
    0.03101965703535825
    0.41562155552674085
    0.06352685287129134
    0.8691775795305148
